# eric7.MicroPython.ConnectionSelectionDialog

Module implementing a dialog to select the port to connect to and the type of the attached device.

### Global Attributes

None

### Classes

ConnectionSelectionDialog | Class implementing a dialog to select the port to connect to and the type of the attached device.

### Functions

None

## ConnectionSelectionDialog

Class implementing a dialog to select the port to connect to and the type of the attached device.

### Derived from

QDialog, Ui_ConnectionSelectionDialog

### Class Attributes

PortNameRole
VidPidRole

### Class Methods

None

### Methods

ConnectionSelectionDialog | Constructor
__updateOK | Private method to update the status of the OK button.
getData | Public method to get the entered data.
on_deviceTypeComboBox_currentTextChanged | Private slot to handle the selection of a device type.
on_portNameComboBox_currentTextChanged | Private slot to handle the selection of a port name.

### Static Methods

None

#### ConnectionSelectionDialog (Constructor)

ConnectionSelectionDialog(ports, currentPort, currentType, parent=None)

Constructor

ports (list of str)
  list of detected ports
currentPort (str)
  port most recently selected
currentType (str)
  device type most recently selected
parent (QWidget (optional))
  reference to the parent widget (defaults to None)

#### ConnectionSelectionDialog.__updateOK

__updateOK()

Private method to update the status of the OK button.

#### ConnectionSelectionDialog.getData

getData()

Public method to get the entered data.

Return:
  tuple containing the VID, PID and name of the selected port and the selected device type

Return Type:
  tuple of (int, int, str, str)

#### ConnectionSelectionDialog.on_deviceTypeComboBox_currentTextChanged

on_deviceTypeComboBox_currentTextChanged(_txt)

Private slot to handle the selection of a device type.

_txt (str)
  selected device description (unused)

#### ConnectionSelectionDialog.on_portNameComboBox_currentTextChanged

on_portNameComboBox_currentTextChanged(_txt)

Private slot to handle the selection of a port name.

_txt (str)
  selected port (unused)

Up